summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/tiletex.cc
diff options
context:
space:
mode:
authorJohanna Ploog <j-p-e-g@users.sourceforge.net>2010-12-16 23:27:51 +0100
committerJohanna Ploog <j-p-e-g@users.sourceforge.net>2010-12-16 23:31:41 +0100
commit476a0770e8dd2137abbaa661244b460f74ed1666 (patch)
tree4ac3e6f109ad7fced770a71e69a790c301ab988c /crawl-ref/source/tiletex.cc
parent0347585d53725310aab07d53576ca2f1dab1dd4a (diff)
downloadcrawl-ref-476a0770e8dd2137abbaa661244b460f74ed1666.tar.gz
crawl-ref-476a0770e8dd2137abbaa661244b460f74ed1666.zip
Split icons out from main.png. Fixes #2981.
This should also allow us to draw clouds beneath monsters.
Diffstat (limited to 'crawl-ref/source/tiletex.cc')
-rw-r--r--crawl-ref/source/tiletex.cc7
1 files changed, 5 insertions, 2 deletions
diff --git a/crawl-ref/source/tiletex.cc b/crawl-ref/source/tiletex.cc
index d96134ea67..b41e1a8204 100644
--- a/crawl-ref/source/tiletex.cc
+++ b/crawl-ref/source/tiletex.cc
@@ -6,6 +6,7 @@
#include "glwrapper.h"
#include "tiledef-dngn.h"
#include "tiledef-gui.h"
+#include "tiledef-icons.h"
#include "tiledef-main.h"
#include "tiledef-player.h"
#include "tiletex.h"
@@ -91,7 +92,7 @@ void TilesTexture::set_info(int tile_max, tile_info_func *info_func)
m_info_func = info_func;
}
// This array should correspond to the TEXTURE_ enum.
const char *ImageManager::filenames[TEX_MAX] =
{
"floor.png",
@@ -99,7 +100,8 @@ const char *ImageManager::filenames[TEX_MAX] =
"feat.png",
"player.png",
"main.png",
- "gui.png"
+ "gui.png",
+ "icons.png"
};
ImageManager::ImageManager()
@@ -128,6 +130,7 @@ bool ImageManager::load_textures(bool need_mips)
m_textures[TEX_DEFAULT].set_info(TILEP_PLAYER_MAX, &tile_main_info);
m_textures[TEX_PLAYER].set_info(TILEP_PLAYER_MAX, &tile_player_info);
m_textures[TEX_GUI].set_info(TILEG_GUI_MAX, &tile_gui_info);
+ m_textures[TEX_ICONS].set_info(TILEI_ICONS_MAX, &tile_icons_info);
return (true);
}
@@ -91,7 +92,7 @@ void TilesTexture::set_info(int tile_max, tile_info_func *info_func)
m_info_func = info_func;
}
-// This array should correspond to the TEXTURE_ enum.
+// This array should correspond to the TEX_ enum.
const char *ImageManager::filenames[TEX_MAX] =
{